Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'tests/PHPUnit/Integration/Plugin/ManagerTest.php')
-rw-r--r--tests/PHPUnit/Integration/Plugin/ManagerTest.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/PHPUnit/Integration/Plugin/ManagerTest.php b/tests/PHPUnit/Integration/Plugin/ManagerTest.php
index 3c4252de77..5cf4470459 100644
--- a/tests/PHPUnit/Integration/Plugin/ManagerTest.php
+++ b/tests/PHPUnit/Integration/Plugin/ManagerTest.php
@@ -147,8 +147,8 @@ class ManagerTest extends IntegrationTestCase
private function assertOnlyTrackerPluginsAreLoaded($expectedPluginNamesLoaded)
{
- // should currently load between 10 and 26 plugins
- $this->assertLessThan(26, count($this->manager->getLoadedPlugins()));
+ // should currently load between 10 and 27 plugins
+ $this->assertLessThan(27, count($this->manager->getLoadedPlugins()));
$this->assertGreaterThan(10, count($this->manager->getLoadedPlugins()));
// we need to make sure it actually only loaded the correct ones